<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="57"/>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="915"/>
        <source>MX Snapshot</source>
        <translation>MX Snapshot - Criador de Imagem ISO do Sistema Operacional</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Snapshot location:</source>
        <translation>Local da imagem do disco:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot é um utilitário que cria uma imagem (ISO) inicializável (bootable) do seu sistema operacional em execução, que pode ser usada para guardar/copiar ou para distribuir. Você pode continuar trabalhando com aplicativos pouco exigentes enquanto ele está em execução.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Espaço usado nas partições / (root ou raiz) e /home:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <location filename="../mainwindow.cpp" line="861"/>
        <source>Snapshot name:</source>
        <translation>Nome do Snapshot:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Select a different snapshot directory</source>
        <translation>Selecione um diretório de snapshot diferente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>lz4</source>
        <translation>lz4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>lzo</source>
        <translation>lzo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>gzip</source>
        <translation>gzip</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>xz</source>
        <translation>xz</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <location filename="../mainwindow.ui" line="313"/>
        <source>TextLabel</source>
        <translation>Rótulo de texto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Downloads</source>
        <translation>Transferências</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="345"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <source>All of the above</source>
        <translation>Tudo os itens acima</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Music</source>
        <translation>Músicas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="366"/>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="373"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>exclude network configurations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>Networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Esta opção reiniciará as senhas&amp;quot;demo&amp;quot; e &amp;quot;root&amp;quot; para as senhas padrões do MX Linux e não copiará quaisquer contas pessoais criadas.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Redefinindo contas (para distribuir para outros)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Type of snapshot:</source>
        <translation>Tipo de snapshot:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Preservar contas (para cópia de segurança pessoal do Sistema Operacional)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>ISO compression scheme:</source>
        <translation>Esquema de compressão ISO:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Edit Exclusion File</source>
        <translation>Editar o arquivo de exclusão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="581"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="642"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="652"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="671"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="678"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="694"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>Used space on / (root): </source>
        <translation>Espaço usado em / (root):</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>estimated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>Used space on /home: </source>
        <translation>Espaço usado em /home:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Espaço livre em %1, onde a pasta de imagem ISO está localizada:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>O espaço livre deve ser suficiente para armazenar os dados compactados de / e de /home

Se necessário, você pode criar mais espaço disponível
removendo imagens anteriores e cópias guardadas/copiadas:
%1 imagens ocupam %2 do espaço em disco.
</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Installing </source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <location filename="../mainwindow.cpp" line="649"/>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="867"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Could not install </source>
        <translation>Não foi possível instalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Building new initrd...</source>
        <translation>Construindo novo initrd...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="350"/>
        <source>Copying the new-iso filesystem...</source>
        <translation>Copiar o sistema de arquivos da nova imagem iso...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="646"/>
        <source>Squashing filesystem...</source>
        <translation>Comprimindo o sistema de arquivos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation>Não foi possível criar o arquivo linuxfs; verifique se há espaço suficiente na partição de destino.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Creating CD/DVD image file...</source>
        <translation>Criar o arquivo de imagem de CD/DVD...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation>Não foi possível criar o arquivo ISO; verifique há espaço suficiente na partição de destino.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="672"/>
        <source>Making hybrid iso</source>
        <translation>Criar imagem iso híbrida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="685"/>
        <source>MX Snapshot completed sucessfully!</source>
        <translation>MX Snapshot ISO completada com sucesso!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="686"/>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Snapshot took %1 to finish.</source>
        <translation>O MX Snapshot ISO demorou %1 para terminar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="688"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation>Obrigado por usar o MX Snapshot ISO; execute em seguida o MX Criador de USB Executável!</translation>
    </message>
    <message>
        <source>Making md5sum</source>
        <translation type="vanished">Criando o md5sum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="733"/>
        <source>Cleaning...</source>
        <translation>Limpando...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <location filename="../mainwindow.cpp" line="1063"/>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="835"/>
        <source>Please wait.</source>
        <translation>Aguarde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Aguarde. Calculando o espaço em disco usado...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="852"/>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Snapshot will use the following settings:*</source>
        <translation>A imagem usará as seguintes configurações:*</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="860"/>
        <source>- Snapshot directory:</source>
        <translation>- diretório de imagens:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>- Kernel to be used:</source>
        <translation>Núcleo (kernel) a ser usado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="868"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>O núcleo (kernel) atual não oferece suporte ao algoritmo de compactação/compressão selecionado, por favor edite o arquivo de configuração e selecione um algoritmo diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="872"/>
        <source>Final chance</source>
        <translation>Última chance</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="873"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>O Snapshot possui agora todas as informações necessárias para criar uma imagem ISO a partir do seu sistema operacional em execução.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="874"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>Demorará algum tempo para terminar, dependendo do tamanho do sistema instalado e da capacidade do computador.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>OK to start?</source>
        <translation>Iniciar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="884"/>
        <source>Output</source>
        <translation>Resultado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="891"/>
        <source>Edit Boot Menu</source>
        <translation>Editar o Menu de Inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="892"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>O programa parará agora para permitir que você edite quaisquer arquivos no diretório de trabalho (work). Clique em Sim para editar o menu de inicialização ou clique em Não para ignorar esta etapa e continuar a criação da imagem ISO.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>All finished!</source>
        <translation>Tudo terminado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1017"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1018"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1019"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>Programa para criar uma instalação externa/live CD do sistema operacional MX Linux em execução</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1021"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1022"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1037"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1045"/>
        <source>Select Snapshot Directory</source>
        <translation>Selecione o diretório Snapshot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1064"/>
        <source>Confirmation</source>
        <translation>Confirmação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1064"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>Você tem certeza de que deseja encerrar o aplicativo?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation>O núcleo (kernel) atual não suporta Squashfs, não pode continuar.</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Você tem que executar este programa como root.</translation>
    </message>
</context>
</TS>
